==> apache-iotdb-1.3.2-source-release.zip: apache-iotdb-1.3.2/iotdb-core/datanode/src/main/java/org/apache/iotdb/db/queryengine/common/schematree/visitor/SchemaTreeDeviceVisitor.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.iotdb.db.queryengine.common.schematree.visitor;

import org.apache.iotdb.commons.path.PartialPath;
import org.apache.iotdb.db.queryengine.common.schematree.DeviceSchemaInfo;
import org.apache.iotdb.db.queryengine.common.schematree.IMeasurementSchemaInfo;
import org.apache.iotdb.db.queryengine.common.schematree.MeasurementSchemaInfo;
import org.apache.iotdb.db.queryengine.common.schematree.node.SchemaMeasurementNode;
import org.apache.iotdb.db.queryengine.common.schematree.node.SchemaNode;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

public class SchemaTreeDeviceVisitor extends SchemaTreeVisitor<DeviceSchemaInfo> {

  public SchemaTreeDeviceVisitor(SchemaNode root, PartialPath pathPattern, boolean isPrefixMatch) {
    super(root, pathPattern, isPrefixMatch);
  }

  @Override
  protected boolean mayTargetNodeType(SchemaNode node) {
    return node.isEntity();
  }

  @Override
  protected boolean acceptInternalMatchedNode(SchemaNode node) {
    return false;
  }

  @Override
  protected boolean acceptFullMatchedNode(SchemaNode node) {
    return node.isEntity();
  }

  @Override
  protected DeviceSchemaInfo generateResult(SchemaNode nextMatchedNode) {
    PartialPath path = getPartialPathFromRootToNode(nextMatchedNode);
    List<IMeasurementSchemaInfo> measurementSchemaInfoList = new ArrayList<>();
    Iterator<SchemaNode> iterator = getChildrenIterator(nextMatchedNode);
    SchemaNode node;
    SchemaMeasurementNode measurementNode;
    while (iterator.hasNext()) {
      node = iterator.next();
      if (node.isMeasurement()) {
        measurementNode = node.getAsMeasurementNode();
        measurementSchemaInfoList.add(
            new MeasurementSchemaInfo(
                measurementNode.getName(),
                measurementNode.getSchema(),
                measurementNode.getAlias(),
                measurementNode.getTagMap()));
      }
    }

    return new DeviceSchemaInfo(
        path,
        nextMatchedNode.getAsEntityNode().isAligned(),
        nextMatchedNode.getAsEntityNode().getTemplateId(),
        measurementSchemaInfoList);
  }
}

==> apache-iotdb-2.0.5-source-release.zip: apache-iotdb-2.0.5/iotdb-core/datanode/src/main/java/org/apache/iotdb/db/queryengine/common/schematree/visitor/SchemaTreeDeviceVisitor.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.iotdb.db.queryengine.common.schematree.visitor;

import org.apache.iotdb.commons.path.PartialPath;
import org.apache.iotdb.db.queryengine.common.schematree.DeviceSchemaInfo;
import org.apache.iotdb.db.queryengine.common.schematree.IMeasurementSchemaInfo;
import org.apache.iotdb.db.queryengine.common.schematree.MeasurementSchemaInfo;
import org.apache.iotdb.db.queryengine.common.schematree.node.SchemaMeasurementNode;
import org.apache.iotdb.db.queryengine.common.schematree.node.SchemaNode;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

public class SchemaTreeDeviceVisitor extends SchemaTreeVisitor<DeviceSchemaInfo> {

  public SchemaTreeDeviceVisitor(SchemaNode root, PartialPath pathPattern, boolean isPrefixMatch) {
    super(root, pathPattern, isPrefixMatch);
  }

  @Override
  protected boolean mayTargetNodeType(SchemaNode node) {
    return node.isEntity();
  }

  @Override
  protected boolean acceptInternalMatchedNode(SchemaNode node) {
    return false;
  }

  @Override
  protected boolean acceptFullMatchedNode(SchemaNode node) {
    return node.isEntity();
  }

  @Override
  protected DeviceSchemaInfo generateResult(SchemaNode nextMatchedNode) {
    PartialPath path = getPartialPathFromRootToNode(nextMatchedNode);
    List<IMeasurementSchemaInfo> measurementSchemaInfoList = new ArrayList<>();
    Iterator<SchemaNode> iterator = getChildrenIterator(nextMatchedNode);
    SchemaNode node;
    SchemaMeasurementNode measurementNode;
    while (iterator.hasNext()) {
      node = iterator.next();
      if (node.isMeasurement()) {
        measurementNode = node.getAsMeasurementNode();
        measurementSchemaInfoList.add(
            new MeasurementSchemaInfo(
                measurementNode.getName(),
                measurementNode.getSchema(),
                measurementNode.getAlias(),
                measurementNode.getTagMap(),
                measurementNode.getAttributeMap()));
      }
    }

    return new DeviceSchemaInfo(
        path,
        nextMatchedNode.getAsEntityNode().isAligned(),
        nextMatchedNode.getAsEntityNode().getTemplateId(),
        measurementSchemaInfoList);
  }
}
